Skip to contents

Confidence interval calculation from bootstrap samples.

Usage

ct_boot_ci(t0, bt, conf = 0.95)

Arguments

t0

the statistic estimated from the original sample, usually the output from ct_overlap_estimates()

bt

a vector of bootstrap statistics, usually the output from ct_boot_estimates()

conf

a (single!) confidence interval to estimate.

Value

A numeric matrix of confidence limits, as returned by overlap::bootCI(). Each row corresponds to one of the estimators supplied in t0 and the two columns give the lower and upper bounds of the confidence interval at the requested level (conf).