The function takes a list of data frames and stacks them into a single data frame. It ensures that all columns from the input data frames in the list are included in the output, filling in missing columns with NA values where necessary.
Examples
x <- data.frame(age = 15, fruit = "Apple", weight = 12)
y <- data.frame(age = 51, fruit = "Tomato")
z <- data.frame(age = 26, fruit = "Lemo", weight = 12, height = 45)
alldf <- list(x,y,z)
ct_stack_df(alldf)
#> # A tibble: 3 × 4
#> weight fruit height age
#> <dbl> <chr> <dbl> <dbl>
#> 1 12 Apple NA 15
#> 2 NA Tomato NA 51
#> 3 12 Lemo 45 26