Reads Camera Trap Data Package (Camtrap DP) dataset into memory.
Taxonomic information
Camtrap DP metadata has a taxonomic property that can contain extra
information for each scientificName found in observations.
Such information can include higher taxonomy (family, order, etc.) and
vernacular names in multiple languages.
The read_camtrapdp() function will automatically include this taxonomic
information in observations, as extra columns starting with taxon..
It will then update the taxonomic scope in the metadata to the unique
taxa() found in the data.
Events
Observations can contain classifications at two levels:
Media-based observations (
observationLevel = "media") are based on a single media file and are directly linked to it viamediaID.Event-based observations (
observationLevel = "event") are based on an event, defined as a combination ofeventID,eventStartandeventEnd. This event can consist of one or more media files, but is not directly linked to these.
The read_camtrapdp() function will automatically assign eventIDs to
media, using media.deploymentID = observations.deploymentID and
observations.eventStart <= media.timestamp <= observations.eventEnd.
Note that this can result in media being linked to multiple events (and thus
being duplicated), for example when events and sub-events were defined.